@@ -48,7 +48,7 @@ fn command(mut args: CommandArgs) -> Result<OutputStream, ShellError> {
     let tag = args.call_info.name_tag.clone();
     let file_name: Tagged<PathBuf> = args.req(0)?;
 
-    let mut df = NuDataFrame::try_from_stream(&mut args.input, &tag.span)?;
+    let (mut df, _) = NuDataFrame::try_from_stream(&mut args.input, &tag.span)?;
 
     let file = File::create(&file_name.item).map_err(|e| {
         ShellError::labeled_error(
